@@ -1,20 +1,88 @@
-from pychess.Utils.const import EMPTY, PAWN, KNIGHT, BISHOP, ROOK, QUEEN, KING, \
-    ATOMICCHESS, BUGHOUSECHESS, CRAZYHOUSECHESS, CAMBODIANCHESS, MAKRUKCHESS, \
-    FISCHERRANDOMCHESS, SITTUYINCHESS, WILDCASTLECHESS, WILDCASTLESHUFFLECHESS, \
-    SUICIDECHESS, GIVEAWAYCHESS, DROP_VARIANTS, BLACK, WHITE, FAN_PIECES, NULL_MOVE, CAS_FLAGS, \
-    NORMALCHESS, PLACEMENTCHESS, THREECHECKCHESS, SETUPCHESS, FEN_START, \
-    chrU2Sign, cordDic, reprCord, reprFile, reprSign, reprSignMakruk, reprSignSittuyin, \
-    A1, A8, B1, B8, \
-    C1, C8, D1, D8, \
-    E1, E8, F1, F8, \
-    G1, G8, H1, H8, \
-    KING_CASTLE, QUEEN_CASTLE, DROP, PROMOTIONS, ENPASSANT, B_OO, B_OOO, W_OO, W_OOO
+from pychess.Utils.const import (
+    EMPTY,
+    PAWN,
+    KNIGHT,
+    BISHOP,
+    ROOK,
+    QUEEN,
+    KING,
+    ATOMICCHESS,
+    BUGHOUSECHESS,
+    CRAZYHOUSECHESS,
+    CAMBODIANCHESS,
+    MAKRUKCHESS,
+    FISCHERRANDOMCHESS,
+    SITTUYINCHESS,
+    WILDCASTLECHESS,
+    WILDCASTLESHUFFLECHESS,
+    SUICIDECHESS,
+    GIVEAWAYCHESS,
+    DROP_VARIANTS,
+    BLACK,
+    WHITE,
+    FAN_PIECES,
+    CAS_FLAGS,
+    NORMALCHESS,
+    PLACEMENTCHESS,
+    THREECHECKCHESS,
+    SETUPCHESS,
+    FEN_START,
+    HAWK,
+    ELEPHANT,
+    SCHESS,
+    LIGHTBRIGADECHESS,
+    chrU2Sign,
+    cordDic,
+    reprCord,
+    reprFile,
+    reprSign,
+    reprSignMakruk,
+    reprSignSittuyin,
+    A1,
+    A8,
+    B1,
+    B8,
+    C1,
+    C8,
+    D1,
+    D8,
+    E1,
+    E8,
+    F1,
+    F8,
+    G1,
+    G8,
+    H1,
+    H8,
+    DROP,
+    PROMOTIONS,
+    ENPASSANT,
+    B_OO,
+    B_OOO,
+    W_OO,
+    W_OOO,
+    QUEEN_CASTLE,
+    KING_CASTLE,
+    GATINGS,
+    HAWK_GATE,
+    HAWK_GATE_AT_ROOK,
+    ELEPHANT_GATE_AT_ROOK,
+    QUEEN_PROMOTION,
+)
 from pychess.Utils.repr import reprColor
 from .ldata import FILE, fileBits
 from .attack import isAttacked
-from .bitboard import clearBit, setBit, bitPosArray
-from .PolyglotHash import pieceHashes, epHashes, \
-    W_OOHash, W_OOOHash, B_OOHash, B_OOOHash, colorHash, holdingHash
+from .bitboard import clearBit, iterBits, setBit, bitPosArray
+from .PolyglotHash import (
+    pieceHashes,
+    epHashes,
+    W_OOHash,
+    W_OOOHash,
+    B_OOHash,
+    B_OOOHash,
+    colorHash,
+    holdingHash,
+)
 
 ################################################################################
 # FEN                                                                          #
@@ -39,18 +107,28 @@ class LBoard:
     fin_kings = ((C1, G1), (C8, G8))
     fin_rooks = ((D1, F1), (D8, F8))
 
-    holding = ({PAWN: 0,
-                KNIGHT: 0,
-                BISHOP: 0,
-                ROOK: 0,
-                QUEEN: 0,
-                KING: 0},
-               {PAWN: 0,
-                KNIGHT: 0,
-                BISHOP: 0,
-                ROOK: 0,
-                QUEEN: 0,
-                KING: 0})
+    holding = (
+        {
+            PAWN: 0,
+            KNIGHT: 0,
+            BISHOP: 0,
+            ROOK: 0,
+            QUEEN: 0,
+            HAWK: 0,
+            ELEPHANT: 0,
+            KING: 0,
+        },
+        {
+            PAWN: 0,
+            KNIGHT: 0,
+            BISHOP: 0,
+            ROOK: 0,
+            QUEEN: 0,
+            HAWK: 0,
+            ELEPHANT: 0,
+            KING: 0,
+        },
+    )
 
     def __init__(self, variant=NORMALCHESS):
         self.variant = variant
@@ -75,8 +153,11 @@ class LBoard:
 
     @property
     def lastMove(self):
-        return self.hist_move[-1] if self.fen_was_applied and len(
-            self.hist_move) > 0 else None
+        return (
+            self.hist_move[-1]
+            if self.fen_was_applied and len(self.hist_move) > 0
+            else None
+        )
 
     def repetitionCount(self, draw_threshold=3):
         rc = 1
@@ -94,18 +175,28 @@ class LBoard:
         self.promoted = [0] * 64
         self.capture_promoting = False
         self.hist_capture_promoting = []
-        self.holding = ({PAWN: 0,
-                         KNIGHT: 0,
-                         BISHOP: 0,
-                         ROOK: 0,
-                         QUEEN: 0,
-                         KING: 0},
-                        {PAWN: 0,
-                         KNIGHT: 0,
-                         BISHOP: 0,
-                         ROOK: 0,
-                         QUEEN: 0,
-                         KING: 0})
+        self.holding = (
+            {
+                PAWN: 0,
+                KNIGHT: 0,
+                BISHOP: 0,
+                ROOK: 0,
+                QUEEN: 0,
+                HAWK: 0,
+                ELEPHANT: 0,
+                KING: 0,
+            },
+            {
+                PAWN: 0,
+                KNIGHT: 0,
+                BISHOP: 0,
+                ROOK: 0,
+                QUEEN: 0,
+                HAWK: 0,
+                ELEPHANT: 0,
+                KING: 0,
+            },
+        )
 
     def iniCambodian(self):
         self.ini_kings = (D1, E8)
@@ -113,14 +204,20 @@ class LBoard:
         self.is_first_move = {KING: [True, True], QUEEN: [True, True]}
         self.hist_is_first_move = []
 
-    def applyFen(self, fenstr):
-        """ Applies the fenstring to the board.
-            If the string is not properly
-            written a SyntaxError will be raised, having its message ending in
-            Pos(%d) specifying the string index of the problem.
-            if an error is found, no changes will be made to the board. """
+    def iniSchess(self):
+        self.virgin = [0, 0]
+        self.hist_virgin = []
 
-        assert not self.fen_was_applied, "The applyFen() method can be used on new LBoard objects only!"
+    def applyFen(self, fenstr):
+        """Applies the fenstring to the board.
+        If the string is not properly
+        written a SyntaxError will be raised, having its message ending in
+        Pos(%d) specifying the string index of the problem.
+        if an error is found, no changes will be made to the board."""
+
+        assert (
+            not self.fen_was_applied
+        ), "The applyFen() method can be used on new LBoard objects only!"
 
         # Set board to empty on Black's turn (which Polyglot-hashes to 0)
         self.blocker = 0
@@ -131,7 +228,7 @@ class LBoard:
         # this variable is a 2-dimmensionnal array, each case containing a bitboard
         # self.boards[color] contains an array of bitboards, each representing the position of the pieces
         # use example : self.boards[color][KNIGHT]
-        self.boards = ([0] * 7, [0] * 7)
+        self.boards = ([0] * 9, [0] * 9)
 
         self.enpassant = None  # cord which can be captured by enpassant or None
         self.color = BLACK
@@ -160,7 +257,7 @@ class LBoard:
         self.hist_opchecked = []
 
         # piece counts
-        self.pieceCount = ([0] * 7, [0] * 7)
+        self.pieceCount = ([0] * 9, [0] * 9)
 
         # initial cords of rooks and kings for castling in Chess960
         if self.variant == FISCHERRANDOMCHESS:
@@ -181,6 +278,9 @@ class LBoard:
         elif self.variant == CAMBODIANCHESS:
             self.iniCambodian()
 
+        elif self.variant == SCHESS:
+            self.iniSchess()
+
         if self.variant in DROP_VARIANTS:
             self.iniHouse()
 
@@ -194,10 +294,12 @@ class LBoard:
             raise SyntaxError(_("FEN needs 6 data fields. \n\n%s") % fenstr)
         elif len(parts) < 2:
             raise SyntaxError(
-                _("FEN needs at least 2 data fields in fenstr. \n\n%s") %
-                fenstr)
+                _("FEN needs at least 2 data fields in fenstr. \n\n%s") % fenstr
+            )
         elif len(parts) >= 7 and self.variant == THREECHECKCHESS:
-            pieceChrs, colChr, castChr, epChr, checksChr, fiftyChr, moveNoChr = parts[:7]
+            pieceChrs, colChr, castChr, epChr, checksChr, fiftyChr, moveNoChr = parts[
+                :7
+            ]
             self.remaining_checks = list(map(int, checksChr.split("+")))
         elif len(parts) >= 6:
             pieceChrs, colChr, castChr, epChr, fiftyChr, moveNoChr = parts[:6]
@@ -214,33 +316,37 @@ class LBoard:
         else:
             pieceChrs, colChr = parts
 
-        # Try to validate some information
-        # TODO: This should be expanded and perhaps moved
-
         slashes = pieceChrs.count("/")
         if slashes < 7:
             raise SyntaxError(
-                _("Needs 7 slashes in piece placement field. \n\n%s") % fenstr)
+                _("Needs 7 slashes in piece placement field. \n\n%s") % fenstr
+            )
 
         if not colChr.lower() in ("w", "b"):
             raise SyntaxError(
-                _("Active color field must be one of w or b. \n\n%s") % fenstr)
+                _("Active color field must be one of w or b. \n\n%s") % fenstr
+            )
 
         if castChr != "-":
             for Chr in castChr:
-                valid_chars = "ABCDEFGHKQ" if self.variant == FISCHERRANDOMCHESS or self.variant == SETUPCHESS else "KQ"
+                if self.variant == FISCHERRANDOMCHESS or self.variant == SETUPCHESS:
+                    valid_chars = "ABCDEFGHKQ"
+                elif self.variant == CAMBODIANCHESS:
+                    valid_chars = "DE"
+                elif self.variant == SCHESS:
+                    valid_chars = "KQABCDEFGH"
+                elif self.variant == LIGHTBRIGADECHESS:
+                    valid_chars = ""
+                else:
+                    valid_chars = "KQ"
+
                 if Chr.upper() not in valid_chars:
-                    if self.variant == CAMBODIANCHESS:
-                        pass
-                        # sjaakii uses DEde in cambodian starting fen to indicate
-                        # that queens and kings are virgins (not moved yet)
-                    else:
-                        raise SyntaxError(_("Castling availability field is not legal. \n\n%s")
-                                          % fenstr)
+                    raise SyntaxError(
+                        _("Castling availability field is not legal. \n\n%s") % fenstr
+                    )
 
         if epChr != "-" and epChr not in cordDic:
-            raise SyntaxError(_("En passant cord is not legal. \n\n%s") %
-                              fenstr)
+            raise SyntaxError(_("En passant cord is not legal. \n\n%s") % fenstr)
 
         # Parse piece placement field
         promoted = False
@@ -257,7 +363,9 @@ class LBoard:
                         color = char.islower() and BLACK or WHITE
                         piece = chrU2Sign[char.upper()]
                         self.holding[color][piece] += 1
-                        self.hash ^= holdingHash[color][piece][self.holding[color][piece]]
+                        self.hash ^= holdingHash[color][piece][
+                            self.holding[color][piece]
+                        ]
                         continue
                     else:
                         break
@@ -277,8 +385,7 @@ class LBoard:
                         promoted = False
 
                     if self.variant == CAMBODIANCHESS:
-                        if piece == KING and self.kings[
-                                color] != self.ini_kings[color]:
+                        if piece == KING and self.kings[color] != self.ini_kings[color]:
                             self.is_first_move[KING][color] = False
                         if piece == QUEEN and cord != self.ini_queens[color]:
                             self.is_first_move[QUEEN][color] = False
@@ -301,6 +408,7 @@ class LBoard:
             self.setColor(BLACK)
 
         # Parse castling availability
+        # TODO: S-Chess gating
 
         castling = 0
         for char in castChr:
@@ -321,16 +429,16 @@ class LBoard:
                         self.ini_rooks[0][1] = reprFile.index(char.lower())
                 elif char == "K":
                     castling |= W_OO
-                    self.ini_rooks[0][1] = rank1.rfind('R')
+                    self.ini_rooks[0][1] = rank1.rfind("R")
                 elif char == "Q":
                     castling |= W_OOO
-                    self.ini_rooks[0][0] = rank1.find('R')
+                    self.ini_rooks[0][0] = rank1.find("R")
                 elif char == "k":
                     castling |= B_OO
-                    self.ini_rooks[1][1] = rank8.rfind('r') + 56
+                    self.ini_rooks[1][1] = rank8.rfind("r") + 56
                 elif char == "q":
                     castling |= B_OOO
-                    self.ini_rooks[1][0] = rank8.find('r') + 56
+                    self.ini_rooks[1][0] = rank8.find("r") + 56
             else:
                 if char == "K":
                     castling |= W_OO
@@ -341,8 +449,29 @@ class LBoard:
                 elif char == "q":
                     castling |= B_OOO
 
-        if self.variant in (WILDCASTLECHESS, WILDCASTLESHUFFLECHESS,
-                            FISCHERRANDOMCHESS):
+            if self.variant == SCHESS:
+                if char == "K":
+                    self.virgin[WHITE] = setBit(self.virgin[WHITE], E1)
+                    self.virgin[WHITE] = setBit(self.virgin[WHITE], H1)
+                elif char == "Q":
+                    self.virgin[WHITE] = setBit(self.virgin[WHITE], A1)
+                    self.virgin[WHITE] = setBit(self.virgin[WHITE], E1)
+                elif char == "k":
+                    self.virgin[BLACK] = setBit(self.virgin[BLACK], E8)
+                    self.virgin[BLACK] = setBit(self.virgin[BLACK], H8)
+                elif char == "q":
+                    self.virgin[BLACK] = setBit(self.virgin[BLACK], A8)
+                    self.virgin[BLACK] = setBit(self.virgin[BLACK], E8)
+                else:
+                    side = WHITE if char.isupper() else BLACK
+                    cord = ord(char) - 65 if side == WHITE else ord(char) - 97 + 56
+                    self.virgin[side] = setBit(self.virgin[side], cord)
+
+        if self.variant in (
+            WILDCASTLECHESS,
+            WILDCASTLESHUFFLECHESS,
+            FISCHERRANDOMCHESS,
+        ):
             self.ini_kings[WHITE] = self.kings[WHITE]
             self.ini_kings[BLACK] = self.kings[BLACK]
             if self.variant in (WILDCASTLECHESS, WILDCASTLESHUFFLECHESS):
@@ -393,16 +522,16 @@ class LBoard:
         elif self.variant == ATOMICCHESS:
             if not self.boards[self.color][KING]:
                 return False
-            if -2 < (self.kings[0] >> 3) - (self.kings[1] >> 3) < 2 and -2 < (self.kings[0] & 7) - (self.kings[1] & 7) < 2:
+            if (
+                -2 < (self.kings[0] >> 3) - (self.kings[1] >> 3) < 2
+                and -2 < (self.kings[0] & 7) - (self.kings[1] & 7) < 2
+            ):
                 return False
         if self.checked is None:
             kingcord = self.kings[self.color]
             if kingcord == -1:
                 return False
-            self.checked = isAttacked(self,
-                                      kingcord,
-                                      1 - self.color,
-                                      ischecked=True)
+            self.checked = isAttacked(self, kingcord, 1 - self.color, ischecked=True)
         return self.checked
 
     def opIsChecked(self):
@@ -411,16 +540,16 @@ class LBoard:
         elif self.variant == ATOMICCHESS:
             if not self.boards[1 - self.color][KING]:
                 return False
-            if -2 < (self.kings[0] >> 3) - (self.kings[1] >> 3) < 2 and -2 < (self.kings[0] & 7) - (self.kings[1] & 7) < 2:
+            if (
+                -2 < (self.kings[0] >> 3) - (self.kings[1] >> 3) < 2
+                and -2 < (self.kings[0] & 7) - (self.kings[1] & 7) < 2
+            ):
                 return False
         if self.opchecked is None:
             kingcord = self.kings[1 - self.color]
             if kingcord == -1:
                 return False
-            self.opchecked = isAttacked(self,
-                                        kingcord,
-                                        self.color,
-                                        ischecked=True)
+            self.opchecked = isAttacked(self, kingcord, self.color, ischecked=True)
         return self.opchecked
 
     def willLeaveInCheck(self, move):
@@ -484,7 +613,7 @@ class LBoard:
     def setEnpassant(self, epcord):
         # Strip the square if there's no adjacent enemy pawn to make the capture
         if epcord is not None:
-            sideToMove = (epcord >> 3 == 2 and BLACK or WHITE)
+            sideToMove = epcord >> 3 == 2 and BLACK or WHITE
             fwdPawns = self.boards[sideToMove][PAWN]
             if sideToMove == WHITE:
                 fwdPawns >>= 8
@@ -517,6 +646,27 @@ class LBoard:
         opcolor = 1 - self.color
         castling = self.castling
 
+        kcastle = flag == KING_CASTLE or (
+            self.variant == SCHESS
+            and (
+                (fpiece == KING and fcord - tcord == -2)
+                or (
+                    flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)
+                    and fcord - tcord > 0
+                )
+            )
+        )
+        qcastle = flag == QUEEN_CASTLE or (
+            self.variant == SCHESS
+            and (
+                (fpiece == KING and fcord - tcord == 2)
+                or (
+                    flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)
+                    and fcord - tcord < 0
+                )
+            )
+        )
+
         self.hist_move.append(move)
         self.hist_enpassant.append(self.enpassant)
         self.hist_castling.append(self.castling)
@@ -524,16 +674,20 @@ class LBoard:
         self.hist_fifty.append(self.fifty)
         self.hist_checked.append(self.checked)
         self.hist_opchecked.append(self.opchecked)
-        if self.variant in DROP_VARIANTS:
+        if self.variant in DROP_VARIANTS and self.variant != SCHESS:
             self.hist_capture_promoting.append(self.capture_promoting)
         if self.variant == CAMBODIANCHESS:
-            self.hist_is_first_move.append({KING: self.is_first_move[KING][:],
-                                            QUEEN: self.is_first_move[QUEEN][:]})
+            self.hist_is_first_move.append(
+                {KING: self.is_first_move[KING][:], QUEEN: self.is_first_move[QUEEN][:]}
+            )
+        elif self.variant == SCHESS:
+            self.hist_virgin.append(self.virgin[:])
 
         self.opchecked = None
         self.checked = None
 
-        if flag == NULL_MOVE:
+        # null move
+        if fcord == tcord and flag != DROP and flag != QUEEN_PROMOTION:
             self.setColor(opcolor)
             self.plyCount += 1
             return move
@@ -543,15 +697,31 @@ class LBoard:
                 self.is_first_move[KING][color] = False
             elif fpiece == QUEEN and self.is_first_move[QUEEN][color]:
                 self.is_first_move[QUEEN][color] = False
+        elif self.variant == SCHESS:
+            if qcastle:
+                self.virgin[color] = clearBit(self.virgin[color], self.ini_kings[color])
+                self.virgin[color] = clearBit(
+                    self.virgin[color], self.ini_rooks[color][0]
+                )
+            elif kcastle:
+                self.virgin[color] = clearBit(self.virgin[color], self.ini_kings[color])
+                self.virgin[color] = clearBit(
+                    self.virgin[color], self.ini_rooks[color][1]
+                )
+            elif fcord in iterBits(self.virgin[color]):
+                self.virgin[color] = clearBit(self.virgin[color], fcord)
 
         # Castling moves can be represented strangely, so normalize them.
-        if flag in (KING_CASTLE, QUEEN_CASTLE):
-            side = flag - QUEEN_CASTLE
+        if kcastle or qcastle:
+            side = 0 if qcastle else 1
             fpiece = KING
             tpiece = EMPTY  # In FRC, there may be a rook there, but the king doesn't capture it.
+            gcord = fcord  # save gating cord
             fcord = self.ini_kings[color]
-            if FILE(fcord) == 3 and self.variant in (WILDCASTLECHESS,
-                                                     WILDCASTLESHUFFLECHESS):
+            if FILE(fcord) == 3 and self.variant in (
+                WILDCASTLECHESS,
+                WILDCASTLESHUFFLECHESS,
+            ):
                 side = 0 if side == 1 else 1
             tcord = self.fin_kings[color][side]
             rookf = self.ini_rooks[color][side]
@@ -570,11 +740,16 @@ class LBoard:
                 else:
                     if self.variant == CRAZYHOUSECHESS:
                         self.holding[color][tpiece] += 1
-                        self.hash ^= holdingHash[color][tpiece][self.holding[color][tpiece]]
+                        self.hash ^= holdingHash[color][tpiece][
+                            self.holding[color][tpiece]
+                        ]
                     self.capture_promoting = False
             elif self.variant == ATOMICCHESS:
                 from pychess.Variants.atomic import piecesAround
-                apieces = [(fcord, fpiece, color), ]
+
+                apieces = [
+                    (fcord, fpiece, color),
+                ]
                 for acord, apiece, acolor in piecesAround(self, tcord):
                     if apiece != PAWN and acord != fcord:
                         self._removePiece(acord, apiece, acolor)
@@ -598,7 +773,7 @@ class LBoard:
         else:
             self._removePiece(fcord, fpiece, color)
 
-        if flag in (KING_CASTLE, QUEEN_CASTLE):
+        if kcastle or qcastle:
             self._removePiece(rookf, ROOK, color)
             self._addPiece(rookt, ROOK, color)
             self.hasCastled[color] = True
@@ -612,7 +787,10 @@ class LBoard:
                 self.hash ^= holdingHash[color][PAWN][self.holding[color][PAWN]]
             elif self.variant == ATOMICCHESS:
                 from pychess.Variants.atomic import piecesAround
-                apieces = [(fcord, fpiece, color), ]
+
+                apieces = [
+                    (fcord, fpiece, color),
+                ]
                 for acord, apiece, acolor in piecesAround(self, tcord):
                     if apiece != PAWN and acord != fcord:
                         self._removePiece(acord, apiece, acolor)
@@ -638,8 +816,14 @@ class LBoard:
                 elif tpiece != EMPTY:
                     self.promoted[tcord] = 0
 
-        if self.variant == ATOMICCHESS and (tpiece != EMPTY or
-                                            flag == ENPASSANT):
+        if flag in GATINGS:
+            gpiece = HAWK if flag in (HAWK_GATE, HAWK_GATE_AT_ROOK) else ELEPHANT
+            self.holding[color][gpiece] -= 1
+            self.hash ^= holdingHash[color][gpiece][self.holding[color][gpiece]]
+            self.pieceCount[color][gpiece] += 1
+            self._addPiece(gcord if (kcastle or qcastle) else fcord, gpiece, color)
+
+        if self.variant == ATOMICCHESS and (tpiece != EMPTY or flag == ENPASSANT):
             self.pieceCount[color][fpiece] -= 1
         else:
             self._addPiece(tcord, fpiece, color)
@@ -657,7 +841,9 @@ class LBoard:
         # Clear castle flags
         king = self.ini_kings[color]
         wildcastle = FILE(king) == 3 and self.variant in (
-            WILDCASTLECHESS, WILDCASTLESHUFFLECHESS)
+            WILDCASTLECHESS,
+            WILDCASTLESHUFFLECHESS,
+        )
         if fpiece == KING:
             castling &= ~CAS_FLAGS[color][0]
             castling &= ~CAS_FLAGS[color][1]
@@ -703,21 +889,51 @@ class LBoard:
 
         flag = move >> 12
 
-        if flag == NULL_MOVE:
-            self.setColor(color)
-            return
-
         fcord = (move >> 6) & 63
         tcord = move & 63
         tpiece = self.arBoard[tcord]
 
+        if fcord == tcord and flag != DROP and flag != QUEEN_PROMOTION:
+            self.setColor(color)
+            return
+
+        if flag in GATINGS:
+            gpiece = HAWK if flag in (HAWK_GATE, HAWK_GATE_AT_ROOK) else ELEPHANT
+            self.holding[color][gpiece] += 1
+            self.hash ^= holdingHash[color][gpiece][self.holding[color][gpiece]]
+            self.pieceCount[color][gpiece] -= 1
+            self._removePiece(fcord, gpiece, color)
+
+        kcastle = flag == KING_CASTLE or (
+            self.variant == SCHESS
+            and (
+                (tpiece == KING and fcord - tcord == -2)
+                or (
+                    flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)
+                    and fcord - tcord > 0
+                )
+            )
+        )
+        qcastle = flag == QUEEN_CASTLE or (
+            self.variant == SCHESS
+            and (
+                (tpiece == KING and fcord - tcord == 2)
+                or (
+                    flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)
+                    and fcord - tcord < 0
+                )
+            )
+        )
+
         # Castling moves can be represented strangely, so normalize them.
-        if flag in (KING_CASTLE, QUEEN_CASTLE):
-            side = flag - QUEEN_CASTLE
+        if kcastle or qcastle:
+            side = 0 if qcastle else 1
             tpiece = KING
             fcord = self.ini_kings[color]
-            if FILE(fcord) == 3 and self.variant in (WILDCASTLECHESS,
-                                                     WILDCASTLESHUFFLECHESS):
+            if FILE(fcord) == 3 and self.variant in (
+                WILDCASTLECHESS,
+                WILDCASTLESHUFFLECHESS,
+            ):
                 side = 0 if side == 1 else 1
             tcord = self.fin_kings[color][side]
             rookf = self.ini_rooks[color][side]
@@ -771,15 +987,20 @@ class LBoard:
 
         # Put back moved piece
         if flag == DROP:
-            self.holding[color][tpiece] += 1
+            try:
+                self.holding[color][tpiece] += 1
+            except KeyError:
+                print(move, color, tpiece, self.holding)
+                print(self)
             self.hash ^= holdingHash[color][tpiece][self.holding[color][tpiece]]
             self.pieceCount[color][tpiece] -= 1
         else:
-            if not (self.variant == ATOMICCHESS and
-                    (cpiece != EMPTY or flag == ENPASSANT)):
+            if not (
+                self.variant == ATOMICCHESS and (cpiece != EMPTY or flag == ENPASSANT)
+            ):
                 self._addPiece(fcord, tpiece, color)
 
-        if self.variant in DROP_VARIANTS:
+        if self.variant in DROP_VARIANTS and self.variant != SCHESS:
             if flag != DROP:
                 if self.promoted[tcord] and (flag not in PROMOTIONS):
                     self.promoted[fcord] = 1
@@ -791,6 +1012,8 @@ class LBoard:
 
         if self.variant == CAMBODIANCHESS:
             self.is_first_move = self.hist_is_first_move.pop()
+        elif self.variant == SCHESS:
+            self.virgin = self.hist_virgin.pop()
 
         self.setColor(color)
 
@@ -803,16 +1026,24 @@ class LBoard:
         self.plyCount -= 1
 
     def __eq__(self, other):
-        if not (other is not None and
-                self.fen_was_applied and other.fen_was_applied and
-                self.hash == other.hash and self.plyCount == other.plyCount):
+        if not (
+            other is not None
+            and self.fen_was_applied
+            and other.fen_was_applied
+            and self.hash == other.hash
+            and self.plyCount == other.plyCount
+        ):
             return False
 
         b0, b1 = self.prev, other.prev
         ok = True
         while ok and b0 is not None and b1 is not None:
-            if not (b0.fen_was_applied and b1.fen_was_applied and
-                    b0.hash == b1.hash and b0.plyCount == b1.plyCount):
+            if not (
+                b0.fen_was_applied
+                and b1.fen_was_applied
+                and b0.hash == b1.hash
+                and b0.plyCount == b1.plyCount
+            ):
                 ok = False
             else:
                 b0, b1 = b0.prev, b1.prev
@@ -848,25 +1079,29 @@ class LBoard:
 
     def prepr(self, ascii=False):
         if not self.fen_was_applied:
-            return ("LBoard without applied FEN")
+            return "LBoard without applied FEN"
         b = "#" + reprColor[self.color] + " "
         b += self.reprCastling() + " "
         b += self.enpassant is not None and reprCord[self.enpassant] or "-"
         b += "\n# "
-        rows = [self.arBoard[i:i + 8] for i in range(0, 64, 8)][::-1]
+        rows = [self.arBoard[i : i + 8] for i in range(0, 64, 8)][::-1]
         for r, row in enumerate(rows):
             for i, piece in enumerate(row):
                 if piece != EMPTY:
                     if bitPosArray[(7 - r) * 8 + i] & self.friends[WHITE]:
                         assert self.boards[WHITE][
-                            piece], "self.boards doesn't match self.arBoard !!!"
-                        sign = reprSign[piece] if ascii else FAN_PIECES[WHITE][
-                            piece]
+                            piece
+                        ], "self.boards doesn't match self.arBoard !!!"
+                        sign = reprSign[piece] if ascii else FAN_PIECES[WHITE][piece]
                     else:
                         assert self.boards[BLACK][
-                            piece], "self.boards doesn't match self.arBoard !!!"
-                        sign = reprSign[piece].lower(
-                        ) if ascii else FAN_PIECES[BLACK][piece]
+                            piece
+                        ], "self.boards doesn't match self.arBoard !!!"
+                        sign = (
+                            reprSign[piece].lower()
+                            if ascii
+                            else FAN_PIECES[BLACK][piece]
+                        )
                     b += sign
                 else:
                     b += "."
@@ -876,18 +1111,24 @@ class LBoard:
         if self.variant in DROP_VARIANTS:
             for color in (BLACK, WHITE):
                 holding = self.holding[color]
-                b += "\n# [%s]" % "".join([reprSign[
-                    piece] if ascii else FAN_PIECES[color][piece] * holding[
-                        piece] for piece in holding if holding[piece] > 0])
+                b += "\n# [%s]" % "".join(
+                    [
+                        reprSign[piece]
+                        if ascii
+                        else FAN_PIECES[color][piece] * holding[piece]
+                        for piece in holding
+                        if holding[piece] > 0
+                    ]
+                )
         return b
 
     def __repr__(self):
         return self.prepr()
 
-    def asFen(self, enable_bfen=True):
+    def asFen(self, enable_bfen=False):
         fenstr = []
 
-        rows = [self.arBoard[i:i + 8] for i in range(0, 64, 8)][::-1]
+        rows = [self.arBoard[i : i + 8] for i in range(0, 64, 8)][::-1]
         for r, row in enumerate(rows):
             empty = 0
             for i, piece in enumerate(row):
@@ -955,6 +1196,26 @@ class LBoard:
             if not cast:
                 cast = "-"
             fenstr.append(cast)
+        elif self.variant == SCHESS:
+            # TODO: remove redundant letters
+            cast = ""
+            if self.castling & W_OO:
+                cast += "K"
+            if self.castling & W_OOO:
+                cast += "Q"
+            if self.holding[WHITE][HAWK] > 0 or self.holding[WHITE][ELEPHANT] > 0:
+                for bit in iterBits(self.virgin[WHITE]):
+                    cast += "ABCDEFGH"[bit]
+            if self.castling & B_OO:
+                cast += "k"
+            if self.castling & B_OOO:
+                cast += "q"
+            if self.holding[BLACK][HAWK] > 0 or self.holding[BLACK][ELEPHANT] > 0:
+                for bit in iterBits(self.virgin[BLACK]):
+                    cast += "abcdefgh"[bit - 56]
+            if not cast:
+                cast = "-"
+            fenstr.append(cast)
         else:
             fenstr.append(self.reprCastling())
         fenstr.append(" ")
@@ -1016,6 +1277,9 @@ class LBoard:
             copy.holding = (self.holding[0].copy(), self.holding[1].copy())
             copy.capture_promoting = self.capture_promoting
             copy.hist_capture_promoting = self.hist_capture_promoting[:]
+            if self.variant == SCHESS:
+                copy.virgin = self.virgin[:]
+                copy.hist_virgin = self.hist_virgin[:]
         elif self.variant == ATOMICCHESS:
             copy.hist_exploding_around = [a[:] for a in self.hist_exploding_around]
         elif self.variant == THREECHECKCHESS:
@@ -1023,8 +1287,10 @@ class LBoard:
         elif self.variant == CAMBODIANCHESS:
             copy.ini_kings = self.ini_kings
             copy.ini_queens = self.ini_queens
-            copy.is_first_move = {KING: self.is_first_move[KING][:],
-                                  QUEEN: self.is_first_move[QUEEN][:]}
+            copy.is_first_move = {
+                KING: self.is_first_move[KING][:],
+                QUEEN: self.is_first_move[QUEEN][:],
+            }
             copy.hist_is_first_move = self.hist_is_first_move[:]
 
         copy.fen_was_applied = self.fen_was_applied
