@@ -2,17 +2,21 @@
 from pychess.Utils.const import HORDECHESS, VARIANTS_OTHER_NONSTANDARD
 from pychess.Utils.Board import Board
 
-HORDESTART = "rnbqkbnr/pppppppp/8/1PP2PP1/PPPPPPPP/PPPPPPPP/PPPPPPPP/PPPPPPPP w kq - 0 1"
+HORDESTART = (
+    "rnbqkbnr/pppppppp/8/1PP2PP1/PPPPPPPP/PPPPPPPP/PPPPPPPP/PPPPPPPP w kq - 0 1"
+)
 
 
 class HordeBoard(Board):
-    """:Description: Lichess horde: https://lichess.org/variant/horde
-    """
+    """:Description: Lichess horde: https://lichess.org/variant/horde"""
+
     variant = HORDECHESS
-    __desc__ = _("Black have to capture all white pieces to win.\n" +
-                 "White wants to checkmate as usual.\n" +
-                 "White pawns on the first rank may move two squares,\n" +
-                 "similar to pawns on the second rank.")
+    __desc__ = _(
+        "Black have to capture all white pieces to win.\n"
+        + "White wants to checkmate as usual.\n"
+        + "White pawns on the first rank may move two squares,\n"
+        + "similar to pawns on the second rank."
+    )
     name = _("Horde")
     cecp_name = "horde"
     need_initial_board = True
