@@ -6,11 +6,14 @@ from pychess.Utils.Board import Board
 
 class LosersBoard(Board):
     """:Description: The Losers variant is a game where the concept is to get rid of all your
-        pieces before you opponent does. On a players turn if a piece can be taken it must be taken
-        otherwise a normal chess move can be played
+    pieces before you opponent does. On a players turn if a piece can be taken it must be taken
+    otherwise a normal chess move can be played
     """
+
     variant = LOSERSCHESS
-    __desc__ = _("FICS losers: http://www.freechess.org/Help/HelpFiles/losers_chess.html")
+    __desc__ = _(
+        "FICS losers: http://www.freechess.org/Help/HelpFiles/losers_chess.html"
+    )
     name = _("Losers")
     cecp_name = "losers"
     need_initial_board = False
@@ -19,6 +22,5 @@ class LosersBoard(Board):
 
 
 def testKingOnly(board):
-    """ Checks to see if if a winning position has been acheived
-    """
+    """Checks to see if if a winning position has been acheived"""
     return bin(board.friends[board.color]).count("1") == 1
