@@ -7,7 +7,7 @@ from pychess.Utils.Board import Board
 
 
 class RandomBoard(Board):
-    """ :Description:
+    """:Description:
     * Randomly chosen pieces (two queens or three rooks possible)
     * Exactly one king of each color
     * Pieces placed randomly behind the pawns
@@ -16,12 +16,14 @@ class RandomBoard(Board):
     """
 
     variant = RANDOMCHESS
-    __desc__ = _("FICS wild/3: http://www.freechess.org/Help/HelpFiles/wild.html\n" +
-                 "* Randomly chosen pieces (two queens or three rooks possible)\n" +
-                 "* Exactly one king of each color\n" +
-                 "* Pieces placed randomly behind the pawns\n" +
-                 "* No castling\n" +
-                 "* Black's arrangement mirrors white's")
+    __desc__ = _(
+        "FICS wild/3: http://www.freechess.org/Help/HelpFiles/wild.html\n"
+        + "* Randomly chosen pieces (two queens or three rooks possible)\n"
+        + "* Exactly one king of each color\n"
+        + "* Pieces placed randomly behind the pawns\n"
+        + "* No castling\n"
+        + "* Black's arrangement mirrors white's"
+    )
     name = _("Random")
     cecp_name = "wild/3"
     need_initial_board = True
@@ -35,16 +37,15 @@ class RandomBoard(Board):
             Board.__init__(self, setup=setup, lboard=lboard)
 
     def random_start(self):
-        back_rank = random.sample(('r', 'n', 'b', 'q') * 16, 7)
-        back_rank.append('k')
+        back_rank = random.sample(("r", "n", "b", "q") * 16, 7)
+        back_rank.append("k")
         random.shuffle(back_rank)
-        fen = ''.join(back_rank)
-        fen = fen + '/pppppppp/8/8/8/8/PPPPPPPP/' + fen.upper() + ' w - - 0 1'
-
-#        return tmp
+        fen = "".join(back_rank)
+        fen = fen + "/pppppppp/8/8/8/8/PPPPPPPP/" + fen.upper() + " w - - 0 1"
+        return fen
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     Board = RandomBoard(True)
     for i in range(10):
         print(Board.random_start())
