@@ -8,14 +8,17 @@ from pychess.Utils.Board import Board
 
 class ShuffleBoard(Board):
     """:Description: The shuffle variant uses the standard chess rules with the exception
-        no castling is allowed and the back rank is shuffled around
+    no castling is allowed and the back rank is shuffled around
     """
+
     variant = SHUFFLECHESS
     __desc__ = _(
-        "xboard nocastle: http://home.hccnet.nl/h.g.muller/engine-intf.html#8\n" +
-        "FICS wild/2: http://www.freechess.org/Help/HelpFiles/wild.html\n" +
-        "* Random arrangement of the pieces behind the pawns\n" +
-        "* No castling\n" + "* Black's arrangement mirrors white's")
+        "xboard nocastle: http://home.hccnet.nl/h.g.muller/engine-intf.html#8\n"
+        + "FICS wild/2: http://www.freechess.org/Help/HelpFiles/wild.html\n"
+        + "* Random arrangement of the pieces behind the pawns\n"
+        + "* No castling\n"
+        + "* Black's arrangement mirrors white's"
+    )
     name = _("Shuffle")
     cecp_name = "nocastle"
     need_initial_board = True
@@ -29,14 +32,14 @@ class ShuffleBoard(Board):
             Board.__init__(self, setup=setup, lboard=lboard)
 
     def shuffle_start(self):
-        back_rank = ['r', 'n', 'b', 'q', 'k', 'b', 'n', 'r']
+        back_rank = ["r", "n", "b", "q", "k", "b", "n", "r"]
         random.shuffle(back_rank)
-        fen = ''.join(back_rank)
-        fen = fen + '/pppppppp/8/8/8/8/PPPPPPPP/' + fen.upper() + ' w - - 0 1'
+        fen = "".join(back_rank)
+        fen = fen + "/pppppppp/8/8/8/8/PPPPPPPP/" + fen.upper() + " w - - 0 1"
         return fen
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     Board = ShuffleBoard(True)
     for i in range(10):
         print(Board.shuffle_start())
